Modules
-------

Learn
^^^^^

.. automodule:: caspo.learn
    :members:


Classify
^^^^^^^^

.. automodule:: caspo.classify
    :members:


Design
^^^^^^

.. automodule:: caspo.design
    :members:


Predict
^^^^^^^

.. automodule:: caspo.predict
    :members:


Control
^^^^^^^

.. automodule:: caspo.control
    :members:


Visualize
^^^^^^^^^

.. automodule:: caspo.visualize
    :members: